%%
%% This is file 'acomen17.cls',
%% the class file for the acomen 2017 book of abstracts.
%%

\NeedsTeXFormat{LaTeX2e}
\ProvidesClass{acomen17}[2013/02/20 v1.0 ACOMEN 2017 book of abstracts class]

\LoadClass[a4paper,11pt]{article}

% packages

\usepackage[english,british]{babel}

\usepackage[oldstyle]{libertine} % a bit lighter than Times--no osf in math
\usepackage[T1]{fontenc}

\DeclareSymbolFont{numbers}{T1}{LinuxLibertineT-TLF}{m}{n}
\SetSymbolFont{numbers}{bold}{T1}{LinuxLibertineT-TLF}{bx}{n}

  \DeclareMathSymbol{0}\mathalpha{numbers}{"30}
  \DeclareMathSymbol{1}\mathalpha{numbers}{"31}
  \DeclareMathSymbol{2}\mathalpha{numbers}{"32}
  \DeclareMathSymbol{3}\mathalpha{numbers}{"33}
  \DeclareMathSymbol{4}\mathalpha{numbers}{"34}
  \DeclareMathSymbol{5}\mathalpha{numbers}{"35}
  \DeclareMathSymbol{6}\mathalpha{numbers}{"36}
  \DeclareMathSymbol{7}\mathalpha{numbers}{"37}
  \DeclareMathSymbol{8}\mathalpha{numbers}{"38}
  \DeclareMathSymbol{9}\mathalpha{numbers}{"39}


\usepackage{graphicx,amsmath,amssymb,subfigure,booktabs,ntheorem}

\usepackage{textcomp} % required to get special symbols
\usepackage[scaled=.85]{beramono}% a typewriter font must be defined
\usepackage[libertine,cmintegrals,cmbraces]{newtxmath}
\usepackage[scr=rsfso]{mathalfa}
\usepackage{bm}% load after all math to give access to bold math


% text size
\textheight 230mm 
\textwidth  145mm 
\oddsidemargin  8mm
\evensidemargin 8mm
\itemsep 0pt
\parindent 7mm
\parsep 0pt


% document structure

\let\acomen@document\document
\def\document{\acomen@document\label{xyzt}}

\let\acomen@enddocument\enddocument
\def\enddocument{\label{endxyzt}\acomen@enddocument}

% page style

\def\ps@plain{
  \let\@oddfoot\@empty
  \let\@evenfoot\@empty
  \let\@oddhead\@empty
  \let\@evenhead\@empty
  \let\@mkboth\@gobbletwo
  \let\sectionmark\@gobble
  \let\subsectionmark\@gobble
  }

% title

\def\@maketitle{%
  \newpage \null
  \thispagestyle{empty}%
  % acomen heading
  \vskip -50pt
  {\noindent\it
  Book of abstracts of the 7$^\text{th}$ International Conference\\
  on Advanced Computational Methods\\
  in Engineering, ACOMEN 2017\\
   18--22 September 2017.}%
  %\rm pp.~\pageref{xyzt}--\pageref{endxyzt}.}%
  \null\vskip 10mm
  % title
  \begin{center}%
    \let \footnote \thanks
    {\Large\bf\lineskip\medskipamount\relax\@title\par}
  \end{center}\par
  \vskip 1.5em}


% authors

\def\append@toks#1#2{#1\expandafter{\the#1#2}}

\newcount\author@count
\newtoks\author@toks
\newtoks\affiliation@toks
\newtoks\email@toks

\def\author#1#2#3{\advance\author@count1
  \append@toks\author@toks{\make@author{#1$^#3$}}%
  \append@toks\email@toks{\make@email{#2}}}

\def\affiliation#1#2#3{\append@toks\affiliation@toks
  {$^#1$ #2, #3\endgraf\medskip}}

\def\make@author#1{#1\advance\author@count-1\relax
  \ifcase\author@count \or\space and \else, \fi}
\def\make@email#1{{\tt#1}\advance\author@count-1\relax
  \ifcase\author@count \else, \fi}

\def\makeauthors{%
  \begin{center}%
    {\large\bf\the\author@toks}%
    \vskip5mm
    {\it\the\affiliation@toks}%
    e-mails: \the\email@toks%
  \end{center}}

% abstract

\renewenvironment{abstract}{ \maketitle\makeauthors\medskip
    \if@twocolumn
      \section*{\abstractname}%
    \else
      \small
      \begin{center}%
        {\bfseries\abstractname\vspace{-1.5em}\vspace{\z@}}%
      \end{center}%
      \quotation
    \fi
    \def\keywords{\medskip\it Key words: }%
    \def\msccodes{\par MSC 2010: }%
  {\if@twocolumn\else\endquotation\fi}}

\def\keywords

% typesetting parameters

\setlength\lineskip{1\p@}
\setlength\normallineskip{1\p@}
\renewcommand\baselinestretch{}
\setlength\parskip{0\p@ \@plus \p@}
\@lowpenalty   51
\@medpenalty  151
\@highpenalty 301



% starting parameters
\pagestyle{plain}
\selectlanguage{british}
\endinput
